A metadata plugin for isbnlib (https://pypi.python.org/pypi/isbnlib) using the service from Ministerio de Cultura of Spain (for books in Spanish).

After install (pip install isbnlib-mcues), a new metadata provider (mcues) is available in isbnlib.
